#
# PySNMP MIB module T11-FC-FABRIC-ADDR-MGR-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-FABRIC-ADDR-MGR-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:29:39 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection", "ValueSizeConstraint")
( FcNameIdOrZero, fcmInstanceIndex, FcDomainIdOrZero, fcmSwitchIndex, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "FcNameIdOrZero", "fcmInstanceIndex", "FcDomainIdOrZero", "fcmSwitchIndex")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( IpAddress, Unsigned32, MibIdentifier, Integer32, TimeTicks, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, mib_2, NotificationType, Counter32, Counter64, ModuleIdentity, iso, Gauge32, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Unsigned32", "MibIdentifier", "Integer32", "TimeTicks", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "mib-2", "NotificationType", "Counter32", "Counter64", "ModuleIdentity", "iso", "Gauge32", "Bits")
( TextualConvention, RowStatus, TruthValue, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "RowStatus", "TruthValue", "DisplayString")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FcFabricAddrMgrMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 137)).setRevisions(("2006-03-02 00:00",))
if mibBuilder.loadTexts: t11FcFabricAddrMgrMIB.setLastUpdated('200603020000Z')
if mibBuilder.loadTexts: t11FcFabricAddrMgrMIB.setOrganization('T11')
if mibBuilder.loadTexts: t11FcFabricAddrMgrMIB.setContactInfo('     Claudio DeSanti\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  Phone: +1 408 853-9172\n                  EMail: cds@cisco.com\n\n                  Keith McCloghrie\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA USA 95134\n                  Phone: +1 408-526-5260\n                  EMail: kzm@cisco.com')
if mibBuilder.loadTexts: t11FcFabricAddrMgrMIB.setDescription("The MIB module for the Fabric Address management\n           functionality defined by the Fibre Channel standards.  For\n           the purposes of this MIB, Fabric Address Manager refers to\n           the functionality of acquiring DomainID(s) as specified in\n           FC-SW-3, and managing Fibre Channel Identifiers as specified\n           in FC-FS.  An instance of 'Fabric Address Manager' software\n           functionality executes in the Principal Switch, and in each\n           other switch.\n\n           After an agent reboot, the values of read-write objects\n           defined in this MIB module are implementation-dependent.\n\n           Copyright (C) The Internet Society (2006).  This version of\n           this MIB module is part of RFC 4439;  see the RFC itself for\n           full legal notices.")
t11FamNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 0))
t11FamMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 1))
t11FamMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 2))
t11FamConfiguration = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 1, 1))
t11FamInfo = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 1, 2))
t11FamNotifyControl = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 1, 3))
class T11FamDomainPriority(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(1,255)

class T11FamDomainInterfaceRole(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("nonPrincipal", 1), ("principalUpstream", 2), ("principalDownsteam", 3), ("isolated", 4), ("down", 5), ("unknown", 6),)

class T11FamState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("other", 1), ("starting", 2), ("unconfigured", 3), ("principalSwitchSelection", 4), ("domainIdDistribution", 5), ("buildFabricPhase", 6), ("reconfigureFabricPhase", 7), ("stable", 8), ("stableWithNoEports", 9), ("noDomains", 10), ("disabled", 11), ("unknown", 12),)

t11FamTable = MibTable((1, 3, 6, 1, 2, 1, 137, 1, 1, 1), )
if mibBuilder.loadTexts: t11FamTable.setDescription('This table contains Fabric Address Manager related\n           parameters that are able to be configured and monitored\n           in a Fibre Channel switch.  For each of the switches\n           (identified by fcmSwitchIndex) managed by a Fibre Channel\n           management instance (identified by fcmInstanceIndex),\n           there is any entry for each Fabric known to that switch.\n           Entries are implicitly created/removed if and when\n           additional Fabrics are created/deleted.')
t11FamEntry = MibTableRow((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricIndex"))
if mibBuilder.loadTexts: t11FamEntry.setDescription('An entry provides information on the local Fabric Address\n           Manager functionality for a Fabric known to a\n           particular switch.')
t11FamFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11FamFabricIndex.setDescription('A unique index value that uniquely identifies a\n           particular Fabric known to a particular switch.\n\n           In a Fabric conformant to FC-SW-3, only a single Fabric\n           can operate within a physical infrastructure, and thus,\n           the value of this Fabric Index will always be 1.\n\n           However, the current standard, FC-SW-4, defines\n           how multiple Fabrics, each with its own management\n           instrumentation, could operate within one (or more)\n           physical infrastructures.  When such multiple Fabrics\n           are in use, this index value is used to uniquely\n           identify a particular Fabric within a physical\n           infrastructure.')
t11FamConfigDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 2), FcDomainIdOrZero()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamConfigDomainId.setDescription("The configured Domain_ID of the particular switch on this\n           Fabric, or zero if no Domain_ID has been configured.\n           The meaning of this object depends on\n           t11FamConfigDomainIdType object.\n\n           If t11FamConfigDomainIdType is 'preferred', then the\n           configured Domain_ID is called the 'preferred Domain_ID'.\n           Valid values are between 0 and 239.  In a situation where\n           this Domain_ID cannot be assigned, any other Domain_ID\n           will be acceptable.  A value of zero means any Domain_ID.\n\n           If t11FamConfigDomainIdType is 'insistent', then the\n           configured Domain_ID is called the 'insistent Domain_ID' and\n           valid values are between 1 and 239.  In a situation where\n           this Domain_ID cannot be assigned, no other Domain_ID is\n           acceptable.\n\n           In both of the above cases, the switch sends an RDI (Request\n           Domain_ID) to request this Domain_ID to the Principal\n           Switch.  If no Domain_ID is able to be granted in the case\n           of 'preferred', or if an 'insistent' Domain_ID is configured\n           but not able to be granted, then it is an error condition.\n           When this error occurs, the switch will continue as if it\n           receives a SW_RJT with a reason/explanation of 'Unable to\n           perform command request'/'Domain_ID not available'.  That\n           is, its E_Ports on that Fabric will be isolated and the\n           administrator informed via a 't11FamDomainIdNotAssigned'\n           notification.\n\n           If t11FamConfigDomainIdType is 'static', then the configured\n           Domain_ID is called the 'static Domain_ID' and valid values\n           are between 1 and 239.  In this situation, there is no\n           Principal Switch in the Fabric and the Domain_ID is simply\n           assigned by configuration, together with the Fabric_Name.\n           A switch configured with a static Domain_ID, on receiving\n           an EFP, BF, RCF, DIA, or RDI SW_ILS, shall reply with an\n           SW_RJT having Reason Code Explanation 'E_Port is Isolated'\n           and shall isolate the receiving E_Port.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamConfigDomainIdType = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("preferred", 1), ("insistent", 2), ("static", 3),)).clone('preferred')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamConfigDomainIdType.setDescription("Type of configured Domain_ID contained in\n           t11FamConfigDomainId.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamAutoReconfigure = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 4), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamAutoReconfigure.setDescription("This object determines how a particular switch\n           responds to certain error conditions.\n\n           The condition that might cause these errors is\n           the merging of two disjoint Fabrics that have\n           overlapping Domain_ID lists.\n\n           If value of this object is 'true', the switch will\n           send an RCF (ReConfigureFabric) to rebuild the\n           Fabric.\n\n           If 'false', the switch will isolate the E_Ports on\n           which the errors happened.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamContiguousAllocation = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 5), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamContiguousAllocation.setDescription("Determines how a particular switch behaves when elected as\n           the Principal Switch.\n\n           If true, the switch will only accept RDIs with a contiguous\n           allocation; specifically, it will reject RDIs with\n           non-contiguous Domain_IDs, and if an RDI for a contiguous\n           Domain_ID is not able to be fulfilled, it will try to\n           replace all the Domain_IDs in the list with contiguous\n           Domain_IDs, and if that fails, the RDI will be rejected.\n\n           If false, then the switch acts normally in granting\n           the Domain_IDs even if they are not contiguous.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 6), T11FamDomainPriority()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamPriority.setDescription("The initial or configured priority of a particular switch\n           to be used in Principal Switch selection process.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamPrincipalSwitchWwn = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 7), FcNameIdOrZero().clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamPrincipalSwitchWwn.setDescription('The WWN of the Principal Switch on this Fabric,\n           or zero-length string if the identity of the principal\n           switch is unknown.')
t11FamLocalSwitchWwn = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 8), FcNameIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamLocalSwitchWwn.setDescription('The WWN of the particular switch on this Fabric.')
t11FamAssignedAreaIdList = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,256))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamAssignedAreaIdList.setDescription("The list of (zero or more) Area_IDs that have been\n           assigned by a particular switch in this Fabric, formatted\n           as an array of octets in ascending order.\n\n           Each octet represents one Area_ID.  So, the list containing\n           Area_IDs 23, 45, 235, and 56 would be formatted as the\n           4-octet string x'172d38eb'.\n\n           A particular area's Area_ID is used as the index into the\n           t11FamAreaTable to get the statistics on that area.")
t11FamGrantedFcIds = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamGrantedFcIds.setDescription("The total number of Fibre Channel Address Identifiers\n           granted (for local use, i.e., with a particular switch's\n           Domain_ID) by the Fabric Address Manager on that switch.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.")
t11FamRecoveredFcIds = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamRecoveredFcIds.setDescription('The total number of Fibre Channel Address Identifiers that\n           have been recovered by the Fabric Address Manager on a\n           particular switch since the switch has been initialized.\n           A recovered Fibre Channel Address Identifier is one that is\n           explicitly returned after previously being used.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11FamFreeFcIds = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 12), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamFreeFcIds.setDescription('The number of Fibre Channel Address Identifiers that are\n           currently unassigned on this Fabric and could be available\n           for assignment either immediately or at some later time.\n\n           The sum of the instances of FreeFcIds and AssignedFcIds\n           corresponding to a particular Fabric is the total number of\n           Fibre Channel Address Identifiers that the local Fabric\n           Address Management is capable of assigning on that Fabric.')
t11FamAssignedFcIds = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 13), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamAssignedFcIds.setDescription('The number of Fibre Channel Address Identifiers that are\n           currently assigned on this Fabric.\n\n           The sum of the instances of FreeFcIds and AssignedFcIds\n           corresponding to a particular Fabric is the total number of\n           Fibre Channel Address Identifiers that the local Fabric\n           Address Management is capable of assigning on that Fabric.')
t11FamAvailableFcIds = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 14), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamAvailableFcIds.setDescription("The number of Fibre Channel Address Identifiers that are\n           unassigned and currently available for immediate assignment\n           on the Fabric, e.g., with the 'Clean Address' bit set to 1.")
t11FamRunningPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 15), T11FamDomainPriority()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamRunningPriority.setDescription('The running priority of a particular switch on this Fabric.\n           This value is initialized to the value of t11FamPriority,\n           and subsequently altered as specified by the procedures\n           defined in FC-SW-3.')
t11FamPrincSwRunningPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 16), T11FamDomainPriority()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamPrincSwRunningPriority.setDescription('The running priority of the Principal Switch on this\n           Fabric.')
t11FamState = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 17), T11FamState()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamState.setDescription('The state of the Fabric Address Manager on a particular\n           switch on this Fabric.')
t11FamLocalPrincipalSwitchSlctns = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamLocalPrincipalSwitchSlctns.setDescription('The number of times a particular switch became the\n           Principal Switch on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11FamPrincipalSwitchSelections = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamPrincipalSwitchSelections.setDescription('The number of Principal Switch selections on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11FamBuildFabrics = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamBuildFabrics.setDescription('The number of non-disruptive fabric reconfigurations (BFs)\n           that have occurred on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11FamFabricReconfigures = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamFabricReconfigures.setDescription('The number of disruptive fabric reconfigurations (RCFs)\n           that have occurred on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11FamDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 22), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamDomainId.setDescription('The Domain_ID of a particular switch on this Fabric or\n           zero if no Domain_ID has been assigned.')
t11FamSticky = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 23), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamSticky.setDescription("An indication of whether a particular switch is supporting\n           the concept of Preferred Domain_IDs via a best-effort\n           attempt to re-assign the same Fibre Channel Address\n           Identifier value to a port on the next occasion when a port\n           requests an assignment on this Fabric.\n\n           If the value of this object is 'true', then the switch is\n           maintaining rows in the t11FamFcIdCacheTable for this\n           Fabric.")
t11FamRestart = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 24), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("nonDisruptive", 1), ("disruptive", 2), ("noOp", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamRestart.setDescription("This object tells the Fabric Address Manager to\n           request a Fabric reconfiguration.\n\n           If this object is set to 'disruptive', then an RCF\n           (ReConfigure Fabric) is generated in the Fabric\n           in order for the Fabric to recover from the errors.\n\n           If this object is set to 'nonDisruptive', then a\n           BF (Build Fabric) is generated in the Fabric.\n\n           No action is taken if this object is set to 'noOp'.\n           The value of the object when read is always 'noOp'.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamRcFabricNotifyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 25), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamRcFabricNotifyEnable.setDescription("An indication of whether or not a particular switch\n           should issue a t11FamFabricChangeNotify notification on\n           sending or receiving ReConfigureFabric (RCF) on a Fabric.\n\n           If the value of the object is 'true', then the\n           notification is generated.  If the value is 'false',\n           notification is not generated.\n\n           If an implementation requires all Fabrics to have the\n           same value, then setting one instance of this object\n           to a new object will result in all corresponding\n           instances being set to that same new value.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 26), TruthValue().clone('true')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamEnable.setDescription("Enables the Fabric Address Manager on this switch\n           on this Fabric.\n\n           If enabled on a Fabric, the switch will participate in\n           Principal Switch selection, and Domain_IDs are assigned\n           dynamically.  If disabled, the switch will not participate\n           in Principal Switch selection, and Domain_IDs are\n           assigned statically.  Thus, the corresponding value of\n           t11FamConfigDomainIdType needs to be 'static'.\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamFabricName = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 1, 1, 27), FcNameIdOrZero()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FamFabricName.setDescription("The WWN that is configured on this switch to be used as\n           the name of this Fabric when the value of t11FamEnable is\n           'false'.\n\n           If the value of t11FamEnable is 'true', this value is not\n           used.\n\n           Fibre Channel requires that:\n               a) all switches in an operational Fabric be\n                  configured with the same Fabric name; and\n               b) each Fabric have a unique Fabric name.\n           If either of these is violated, either by switches within a\n           single Fabric being configured with different Fabric names,\n           or by multiple Fabrics that share management applications\n           or interact in other ways having the same Fabric name,\n           then the behavior of the switches and associated management\n           functions is not specified by Fibre Channel or Internet\n           standards.\n\n\n\n           For the persistence of values across reboots, see the\n           MODULE-IDENTITY's DESCRIPTION clause.")
t11FamIfTable = MibTable((1, 3, 6, 1, 2, 1, 137, 1, 1, 2), )
if mibBuilder.loadTexts: t11FamIfTable.setDescription('This table contains those Fabric Address Manager parameters\n           and status values that are per-interface (identified\n           by an ifIndex value), per-Fabric (identified by a\n           t11FamFabricIndex value), and per-switch (identified by\n           values of fcmInstanceIndex and fcmSwitchIndex).\n\n           An entry in this table is automatically created when\n           an E_Port becomes non-isolated on a particular Fabric.\n\n           An entry is deleted automatically from this table if:\n           a) the corresponding interface is no longer an E_Port (e.g.,\n              a G_Port that is dynamically determined to be an F_Port),\n              and all configuration parameter(s) have default values; or\n           b) the interface identified by ifIndex no longer exists\n              (e.g., because a line-card is physically removed); or\n           c) the row in the t11FamTable corresponding the fabric\n              identified by t11FamFabricID no longer exists.\n\n           Creating an entry in this table via t11FamIfRowStatus\n           provides the means to specify non-default parameter value(s)\n           for an interface at a time when the relevant row in this\n           table does not exist, i.e., because the interface is either\n           down or it is not an E_Port.')
t11FamIfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 137, 1, 1, 2, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricIndex"), (0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: t11FamIfEntry.setDescription('An entry containing information on the interface\n           configuration on the Fabric identified by\n\n\n\n           t11FamFabricIndex.')
t11FamIfRcfReject = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 2, 1, 1), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FamIfRcfReject.setDescription("This object determines if the incoming ReConfigure\n           Fabric (RCF) messages on this interface on this\n           Fabric is accepted or not.  If this object is 'true', then\n           the incoming RCF is rejected.  If 'false', incoming RCF is\n           accepted.\n\n           Note that this object does not apply to the outgoing\n           RCFs generated by this interface.\n\n           Implementations that support write-access to this object\n           can do so under whatever conditions they choose.")
t11FamIfRole = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 2, 1, 2), T11FamDomainInterfaceRole()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamIfRole.setDescription('The role of this interface.')
t11FamIfRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 1, 2, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FamIfRowStatus.setDescription('The status of this row.')
t11FamAreaTable = MibTable((1, 3, 6, 1, 2, 1, 137, 1, 2, 1), )
if mibBuilder.loadTexts: t11FamAreaTable.setDescription("This table contains area assignments per-Fabric by a\n           switch's Fabric Address Manager.  Each octet in\n           t11FamAssignedAreaList is able to be used to index into\n           this table to find information on each area.")
t11FamAreaEntry = MibTableRow((1, 3, 6, 1, 2, 1, 137, 1, 2, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamAreaAreaId"))
if mibBuilder.loadTexts: t11FamAreaEntry.setDescription('An entry gives information on the Area_ID and all\n           Port_IDs that have been assigned within an area for\n           the Fabric identified by t11FamFabricIndex, by the\n           Fabric Address Manager in the switch identified by\n           fcmInstanceIndex and fcmSwitchIndex.')
t11FamAreaAreaId = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 2, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255)))
if mibBuilder.loadTexts: t11FamAreaAreaId.setDescription('The Area_ID of this area.')
t11FamAreaAssignedPortIdList = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 2, 1, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,256))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamAreaAssignedPortIdList.setDescription("The list of Port_IDs which have been assigned in\n           this area and Fabric, formatted as an array of\n           octets in ascending order.  There could be zero or more\n           Port_IDs assigned on this area and Fabric.\n\n           Each octet represents one Port_ID.  So, the list containing\n           the Port_IDs 23, 45, 235, and 56 would be formatted as the\n           4-octet string x'172d38eb'.")
t11FamDatabaseTable = MibTable((1, 3, 6, 1, 2, 1, 137, 1, 2, 2), )
if mibBuilder.loadTexts: t11FamDatabaseTable.setDescription('This table contains all information known by\n           a switch about all the domains that have been\n           assigned in each Fabric.')
t11FamDatabaseEntry = MibTableRow((1, 3, 6, 1, 2, 1, 137, 1, 2, 2, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamDatabaseDomainId"))
if mibBuilder.loadTexts: t11FamDatabaseEntry.setDescription('An entry (conceptual row) in the t11FamDatabaseTable\n           containing information about one Domain_ID in the\n           Fabric identified by t11FamFabricIndex, and known by\n           the switch identified by t11FamFabricIndex and\n           t11FamDatabaseDomainId.')
t11FamDatabaseDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 2, 2, 1, 1), FcDomainIdOrZero().subtype(subtypeSpec=ValueRangeConstraint(1,239)))
if mibBuilder.loadTexts: t11FamDatabaseDomainId.setDescription('The Domain_ID for which this row contains information.\n           The value must be non-zero.')
t11FamDatabaseSwitchWwn = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 2, 2, 1, 2), FcNameIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamDatabaseSwitchWwn.setDescription('The node name (WWN) of the switch to which the\n            corresponding value of t11FamDatabaseDomainId is currently\n            assigned for the particular Fabric.')
t11FamMaxFcIdCacheSize = MibScalar((1, 3, 6, 1, 2, 1, 137, 1, 2, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamMaxFcIdCacheSize.setDescription('The maximum number of Fibre Channel Address Identifiers\n           that are able to be cached in the t11FamFcIdCacheTable.\n           If the number is unknown, the value of this object is\n           zero.')
t11FamFcIdCacheTable = MibTable((1, 3, 6, 1, 2, 1, 137, 1, 2, 4), )
if mibBuilder.loadTexts: t11FamFcIdCacheTable.setDescription('This table contains all the Fibre Channel Address\n           Identifiers that have recently been released by the\n           Fabric Address Manager in a switch.  So, it lists\n           all the Fibre Channel Address Identifiers that have valid\n           WWN-to-Fibre Channel Address Identifier mappings and are\n           currently not assigned to any ports.  These Fibre Channel\n           Address Identifiers were assigned to ports but have since\n           been released.  These cached Fibre Channel Address\n           Identifiers contain only Area_ID and Port_ID information.\n           This cache is kept to provide best-effort re-assignment of\n           same Fibre Channel Address Identifiers; i.e., when an\n           Nx_Port asks for a Fibre Channel Address Identifier, soon\n           after releasing one, the same value is re-assigned, if\n           possible.')
t11FamFcIdCacheEntry = MibTableRow((1, 3, 6, 1, 2, 1, 137, 1, 2, 4, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricIndex"), (0, "T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFcIdCacheWwn"))
if mibBuilder.loadTexts: t11FamFcIdCacheEntry.setDescription('An entry (conceptual row) in the t11FamFcIdCacheTable\n           containing information about one Fibre Channel Address\n           Identifier that was released from a WWN, corresponding to a\n           range of one or more ports connected to the switch\n           (identified by t11FamFabricIndex and t11FamFcIdCacheWwn) in\n           the Fabric (identified by t11FamFabricIndex).  An entry is\n           created when a Fibre Channel Address Identifier is released\n           by the last port in the range.  The oldest entry is deleted\n           if the number of rows in this table reaches\n           t11FamMaxFcIdCacheSize, and its space is required for a new\n           entry.  An entry is also deleted when its Fibre Channel\n           Address Identifier is assigned to a port.')
t11FamFcIdCacheWwn = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 2, 4, 1, 1), FcNameIdOrZero())
if mibBuilder.loadTexts: t11FamFcIdCacheWwn.setDescription('The N_Port_Name (WWN) of the port associated with this\n           entry.')
t11FamFcIdCacheAreaIdPortId = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 2, 4, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,2)).setFixedLength(2)).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamFcIdCacheAreaIdPortId.setDescription('The combination of this object and t11FamFcIdCachePortIds\n           represent one range of Fibre Channel Address Identifiers,\n           which were assigned and later released.  This object\n           contains the Area_ID and Port_ID of the first Fibre\n           Channel Address Identifier in the range.\n\n           Note that this object is only 2 bytes.')
t11FamFcIdCachePortIds = MibTableColumn((1, 3, 6, 1, 2, 1, 137, 1, 2, 4, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FamFcIdCachePortIds.setDescription('The combination of t11FamFcIdCacheAreaIdPortId and this\n           object represent one range of Fibre Channel Address\n           Identifiers, which were assigned and later released.  This\n           object contains the number of (consecutive) Fibre Channel\n           Address Identifiers in the range.')
t11FamNotifyFabricIndex = MibScalar((1, 3, 6, 1, 2, 1, 137, 1, 3, 1), T11FabricIndex()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: t11FamNotifyFabricIndex.setDescription('A unique index value that identifies a particular\n           Fabric for which a particular notification is generated.\n\n           In a Fabric conformant to SW-3, only a single Fabric\n           can operate within a physical infrastructure, and thus,\n           the value of this Fabric Index will always be 1.\n\n           However, the current standard, FC-SW-4, defines\n           how multiple Fabrics, each with its own management\n\n\n\n           instrumentation, could operate within one (or more)\n           physical infrastructures.  In order to accommodate this\n           scenario, this index value is used to uniquely identify a\n           particular Fabric within a physical infrastructure.')
t11FamDomainIdNotAssignedNotify = NotificationType((1, 3, 6, 1, 2, 1, 137, 0, 1)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamLocalSwitchWwn"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamNotifyFabricIndex"),))
if mibBuilder.loadTexts: t11FamDomainIdNotAssignedNotify.setDescription("This notification indicates that a Domain_ID has not\n           been configured or assigned for a particular Fabric,\n           identified by t11FamNotifyFabricIndex, on a particular\n           switch identified by t11FamLocalSwitchWwn.  This could\n           happen under the following conditions, and results in the\n           switch isolating E_Ports on the Fabric:\n\n            - if the switch's request for a configured static\n              Domain_ID is rejected or no other Domain_ID is\n              assigned, then the E_Ports are isolated.")
t11FamNewPrincipalSwitchNotify = NotificationType((1, 3, 6, 1, 2, 1, 137, 0, 2)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamLocalSwitchWwn"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamNotifyFabricIndex"),))
if mibBuilder.loadTexts: t11FamNewPrincipalSwitchNotify.setDescription('This notification indicates that a particular switch,\n           identified by t11FamLocalSwitchWwn, has become the new\n           Principal Switch on the Fabric identified by\n           t11FamNotifyFabricIndex.\n\n           This notification is sent soon after its election as\n           the new Principal Switch, i.e., upon expiration of a\n           Principal Switch selection timer that is equal to\n           twice the Fabric Stability Timeout value (F_S_TOV).')
t11FamFabricChangeNotify = NotificationType((1, 3, 6, 1, 2, 1, 137, 0, 3)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamLocalSwitchWwn"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamNotifyFabricIndex"),))
if mibBuilder.loadTexts: t11FamFabricChangeNotify.setDescription("This notification is sent whenever a particular switch,\n           identified by t11FamLocalSwitchWwn, sends or\n           receives a Build Fabric (BF) or a ReConfigure Fabric\n           (RCF) message on the Fabric identified by\n\n\n\n           t11FamNotifyFabricIndex.\n\n           This notification is not sent if a\n           't11FamNewPrincipalSwitchNotify' notification is sent\n           for the same event.")
t11FamMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 2, 1))
t11FamMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 137, 2, 2))
t11FamMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 137, 2, 1, 1)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamGroup"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamDatabaseGroup"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamAreaGroup"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamNotificationGroup"),))
if mibBuilder.loadTexts: t11FamMIBCompliance.setDescription('The compliance statement for Fibre Channel switches\n           that implement Fabric Address Manager functionality.')
t11FamGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 137, 2, 2, 1)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamConfigDomainId"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamConfigDomainIdType"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamAutoReconfigure"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamContiguousAllocation"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamPriority"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamPrincipalSwitchWwn"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamLocalSwitchWwn"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamAssignedAreaIdList"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamGrantedFcIds"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamRecoveredFcIds"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFreeFcIds"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamAssignedFcIds"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamAvailableFcIds"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamRunningPriority"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamPrincSwRunningPriority"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamState"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamLocalPrincipalSwitchSlctns"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamPrincipalSwitchSelections"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamBuildFabrics"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricReconfigures"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamDomainId"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamSticky"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamRestart"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamRcFabricNotifyEnable"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamEnable"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricName"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamIfRcfReject"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamIfRole"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamIfRowStatus"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamNotifyFabricIndex"),))
if mibBuilder.loadTexts: t11FamGroup.setDescription('A collection of general objects for displaying and\n           configuring Fabric Address management.')
t11FamCommandGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 137, 2, 2, 2)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamRestart"),))
if mibBuilder.loadTexts: t11FamCommandGroup.setDescription('A collection of objects used for initiating an\n           operation on the Fabric.')
t11FamDatabaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 137, 2, 2, 3)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamDatabaseSwitchWwn"),))
if mibBuilder.loadTexts: t11FamDatabaseGroup.setDescription('A collection of objects containing information about\n           Domain-IDs assignments.')
t11FamAreaGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 137, 2, 2, 4)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamAreaAssignedPortIdList"),))
if mibBuilder.loadTexts: t11FamAreaGroup.setDescription('A collection of objects containing information about\n           currently assigned addresses within a domain.')
t11FamCacheGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 137, 2, 2, 5)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamMaxFcIdCacheSize"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFcIdCacheAreaIdPortId"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFcIdCachePortIds"),))
if mibBuilder.loadTexts: t11FamCacheGroup.setDescription('A collection of objects containing information about\n           recently-released Fibre Channel Address Identifiers.')
t11FamNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 137, 2, 2, 6)).setObjects(*(("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamDomainIdNotAssignedNotify"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamNewPrincipalSwitchNotify"), ("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamFabricChangeNotify"),))
if mibBuilder.loadTexts: t11FamNotificationGroup.setDescription('A collection of notifications for status monitoring\n           and notification.')
mibBuilder.exportSymbols("T11-FC-FABRIC-ADDR-MGR-MIB", t11FamAvailableFcIds=t11FamAvailableFcIds, t11FamPriority=t11FamPriority, t11FamFcIdCacheEntry=t11FamFcIdCacheEntry, t11FamSticky=t11FamSticky, t11FamCacheGroup=t11FamCacheGroup, t11FamAreaEntry=t11FamAreaEntry, t11FamFabricIndex=t11FamFabricIndex, t11FamGroup=t11FamGroup, T11FamState=T11FamState, t11FamAreaAssignedPortIdList=t11FamAreaAssignedPortIdList, t11FamConfigDomainIdType=t11FamConfigDomainIdType, t11FamAreaGroup=t11FamAreaGroup, t11FamRecoveredFcIds=t11FamRecoveredFcIds, t11FamConfiguration=t11FamConfiguration, t11FamMIBObjects=t11FamMIBObjects, t11FamAutoReconfigure=t11FamAutoReconfigure, t11FamGrantedFcIds=t11FamGrantedFcIds, t11FamContiguousAllocation=t11FamContiguousAllocation, t11FamDomainIdNotAssignedNotify=t11FamDomainIdNotAssignedNotify, t11FamFabricReconfigures=t11FamFabricReconfigures, t11FamRcFabricNotifyEnable=t11FamRcFabricNotifyEnable, t11FamAreaAreaId=t11FamAreaAreaId, t11FamIfRowStatus=t11FamIfRowStatus, t11FamState=t11FamState, t11FamEntry=t11FamEntry, t11FamMaxFcIdCacheSize=t11FamMaxFcIdCacheSize, T11FamDomainPriority=T11FamDomainPriority, t11FamMIBGroups=t11FamMIBGroups, t11FamFcIdCacheAreaIdPortId=t11FamFcIdCacheAreaIdPortId, t11FamConfigDomainId=t11FamConfigDomainId, t11FamMIBConformance=t11FamMIBConformance, t11FamMIBCompliances=t11FamMIBCompliances, t11FamMIBCompliance=t11FamMIBCompliance, t11FamFabricChangeNotify=t11FamFabricChangeNotify, t11FamIfTable=t11FamIfTable, t11FamLocalSwitchWwn=t11FamLocalSwitchWwn, t11FamPrincipalSwitchSelections=t11FamPrincipalSwitchSelections, t11FamNotifications=t11FamNotifications, t11FamFcIdCacheTable=t11FamFcIdCacheTable, t11FamDatabaseDomainId=t11FamDatabaseDomainId, t11FamEnable=t11FamEnable, t11FamAssignedFcIds=t11FamAssignedFcIds, T11FamDomainInterfaceRole=T11FamDomainInterfaceRole, t11FamRestart=t11FamRestart, t11FamDatabaseSwitchWwn=t11FamDatabaseSwitchWwn, t11FamLocalPrincipalSwitchSlctns=t11FamLocalPrincipalSwitchSlctns, t11FamFabricName=t11FamFabricName, t11FamBuildFabrics=t11FamBuildFabrics, t11FamDomainId=t11FamDomainId, t11FamFcIdCachePortIds=t11FamFcIdCachePortIds, t11FamAssignedAreaIdList=t11FamAssignedAreaIdList, t11FamNewPrincipalSwitchNotify=t11FamNewPrincipalSwitchNotify, PYSNMP_MODULE_ID=t11FcFabricAddrMgrMIB, t11FcFabricAddrMgrMIB=t11FcFabricAddrMgrMIB, t11FamNotifyControl=t11FamNotifyControl, t11FamIfEntry=t11FamIfEntry, t11FamInfo=t11FamInfo, t11FamIfRcfReject=t11FamIfRcfReject, t11FamNotificationGroup=t11FamNotificationGroup, t11FamTable=t11FamTable, t11FamDatabaseTable=t11FamDatabaseTable, t11FamFcIdCacheWwn=t11FamFcIdCacheWwn, t11FamNotifyFabricIndex=t11FamNotifyFabricIndex, t11FamRunningPriority=t11FamRunningPriority, t11FamIfRole=t11FamIfRole, t11FamFreeFcIds=t11FamFreeFcIds, t11FamAreaTable=t11FamAreaTable, t11FamDatabaseEntry=t11FamDatabaseEntry, t11FamCommandGroup=t11FamCommandGroup, t11FamDatabaseGroup=t11FamDatabaseGroup, t11FamPrincSwRunningPriority=t11FamPrincSwRunningPriority, t11FamPrincipalSwitchWwn=t11FamPrincipalSwitchWwn)



#
# PySNMP MIB module APS-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/APS-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:05:50 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint")
( ifIndex, InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex", "InterfaceIndex")
( jnxMibs, ) = mibBuilder.importSymbols("JUNIPER-SMI", "jnxMibs")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( NotificationType, transmission, ObjectIdentity, Counter32, Counter64, IpAddress, MibIdentifier, Bits, ModuleIdentity, Gauge32, Unsigned32, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "NotificationType", "transmission", "ObjectIdentity", "Counter32", "Counter64", "IpAddress", "MibIdentifier", "Bits", "ModuleIdentity", "Gauge32", "Unsigned32", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Integer32")
( StorageType, DisplayString, TimeStamp, TextualConvention, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "DisplayString", "TimeStamp", "TextualConvention", "RowStatus")
apsMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 2636, 3, 24)).setRevisions(("2002-05-08 23:00",))
if mibBuilder.loadTexts: apsMIB.setLastUpdated('200205082300Z')
if mibBuilder.loadTexts: apsMIB.setOrganization('IETF AToMMIB Working Group')
if mibBuilder.loadTexts: apsMIB.setContactInfo('       Jeff Johnson\n                Postal: RedBack Networks. Inc.\n                300 Holger Way\n                San Jose, CA 95134-1362\n                Tel: +1 408 750 5460\n                Email: jeff@redback.com\n\n                Michael Thatcher\n                Postal: RedBack Networks. Inc.\n                300 Holger Way\n                San Jose, CA 95134-1362\n                Tel: +1 408 750 5449\n                Email: thatcher@redback.com\n\n                Jim Kuhfeld\n                Postal: RedBack Networks. Inc.\n                300 Holger Way\n                San Jose, CA 95134-1362\n                Tel: +1 408 750 5465\n                Email: jkuhfeld@redback.com')
if mibBuilder.loadTexts: apsMIB.setDescription('This management information module supports the configuration\n         and management of SONET linear APS groups. The definitions and\n         descriptions used in this MIB have been derived from\n         Synchronous Optical Network (SONET) Transport Systems:\n         Common Generic Criteria, GR-253-CORE Issue 3, September 2000,\n         section 5.3. The MIB is also consistent with the Multiplex\n         Section Protection (MSP) protocol as specified in ITU-T\n         Recommendation G.783, Characteristics of synchronous digital\n         hierarchy (SDH) equipment function blocks, Annex A and B. ')
apsMIBObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1))
apsMIBNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 2))
apsMIBConformance = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3))
class ApsK1K2(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(2,2)
    fixedLength = 2

class ApsSwitchCommand(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))
    namedValues = NamedValues(("noCmd", 1), ("clear", 2), ("lockoutOfProtection", 3), ("forcedSwitchWorkToProtect", 4), ("forcedSwitchProtectToWork", 5), ("manualSwitchWorkToProtect", 6), ("manualSwitchProtectToWork", 7), ("exercise", 8),)

class ApsControlCommand(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("noCmd", 1), ("lockoutWorkingChannel", 2), ("clearLockoutWorkingChannel", 3),)

apsConfig = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1))
apsConfigGroups = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigGroups.setDescription('The count of APS groups. This count includes all rows in\n         apsConfigTable, regardless of the value of apsConfigRowStatus.')
apsConfigTable = MibTable((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2), )
if mibBuilder.loadTexts: apsConfigTable.setDescription('This table lists the APS groups that have been configured\n         on the system.')
apsConfigEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1), ).setIndexNames((1, "APS-MIB", "apsConfigName"))
if mibBuilder.loadTexts: apsConfigEntry.setDescription('A conceptual row in the apsConfigTable.')
apsConfigName = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32)))
if mibBuilder.loadTexts: apsConfigName.setDescription('A textual name for the APS group.')
apsConfigRowStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 2), RowStatus()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigRowStatus.setDescription('The status of this APS group entry.\n\n        An entry may not exist in the active state unless all\n        objects in the entry have an appropriate value. Also,\n        all associated apsChanConfigEntry rows must represent\n        a set of consecutive channel numbers beginning with\n        0 or 1, depending on the selected architecture.\n\n        When set to notInService changes may be made to apsConfigMode,\n        apsConfigRevert, apsConfigDirection, apsConfigExtraTraffic,\n\n\n        apsConfigSdBerThreshold, apsConfigSfBerThreshold,\n        and apsConfigWaitToRestore. Also, associated apsChanConfigTable\n        objects may be added, deleted and modified.')
apsConfigMode = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("onePlusOne", 1), ("oneToN", 2), ("onePlusOneCompatible", 3), ("onePlusOneOptimized", 4),)).clone('onePlusOne')).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigMode.setDescription('The architecture of the APS group.\n\n        onePlusOne\n\n        The 1+1 architecture permanently bridges the working\n        line to the protection line.\n\n        oneToN\n\n        The 1:n architecture allows one protection channel to\n        protect up to n working channels. When a fault is detected\n        on one of the n working channels that channel is bridged\n        over the protection channel.\n\n        onePlusOneCompatible\n\n        This refers to 1 + 1 bidirectional switching compatible with\n        1:n bidirectional switching as specified in ITU-T\n        Recommendation G.783 (04/97) section A.3.4.1. Since this\n        mode necessitates bidirectional switching, apsConfigDirection\n        must be set to bidirectional whenever onePlusOneCompatible is set.\n\n        onePlusOneOptimized\n\n        This refers to 1 + 1 bidirectional switching optimized\n        for a network using predominantly 1 + 1 bidirectional\n        switching as specified in ITU-T Recommendation G.783 (04/97)\n        section B.1. Since this mode necessitates bidirectional\n        switching, apsConfigDirection must be set to bidirectional\n        whenever onePlusOneOptimized is set.\n\n        This object may not be modified if the associated\n        apsConfigRowStatus object is equal to active(1).')
apsConfigRevert = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("nonrevertive", 1), ("revertive", 2),)).clone('nonrevertive')).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigRevert.setDescription('The revertive mode of the APS group.\n\n        nonrevertive\n\n        Traffic remains on the protection line until another switch\n        request is received.\n\n        revertive\n\n        When the condition that caused a switch to the protection\n        line has been cleared the signal is switched back to the\n        working line. Since switching is revertive with the 1:n\n        architecture, apsConfigRevert must be set to revertive if\n        apsConfigMode is set to oneToN.\n\n        Switching may optionally be revertive with the 1+1 architecture.\n\n        This object may not be modified if the associated\n        apsConfigRowStatus object is equal to active(1). ')
apsConfigDirection = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("unidirectional", 1), ("bidirectional", 2),)).clone('unidirectional')).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigDirection.setDescription('The directional mode of the APS group.\n\n        unidirectional\n\n        The unidirectional mode provides protection in one direction.\n\n        bidirectional\n\n        The bidirectional mode provides protection in both\n        directions.\n\n        This object may not be modified if the associated\n\n\n        apsConfigRowStatus object is equal to active(1). ')
apsConfigExtraTraffic = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),)).clone('disabled')).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigExtraTraffic.setDescription("This object enables or disables the transfer of extra traffic\n        on the protection channel in a 1:n architecture. This object\n        must be set to disabled if the architecture is 1+1. It may be\n        necessary to disable this in order to interwork with other SONET\n        network elements that don't support extra traffic.\n\n        This object may not be modified if the associated\n        apsConfigRowStatus object is equal to active(1). ")
apsConfigSdBerThreshold = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(5,9)).clone(5)).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigSdBerThreshold.setDescription('The Signal Degrade Bit Error Rate.\n\n         The negated value of this number is used as the exponent of\n         10 for computing the threshold value for the Bit Error Rate\n         (BER). For example, a value of 5 indicates a BER threshold of\n         10^-5.\n\n         This object may be modified if the associated\n         apsConfigRowStatus object is equal to active(1).')
apsConfigSfBerThreshold = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(3,5)).clone(3)).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigSfBerThreshold.setDescription('The Signal Failure Bit Error Rate.\n\n         The negated value of this number is used as the exponent of\n\n\n         10 for computing the threshold value for the Bit Error Rate\n         (BER). For example, a value of 5 indicates a BER threshold of\n         10^-5.\n\n         This object may be modified if the associated\n         apsConfigRowStatus object is equal to active(1).')
apsConfigWaitToRestore = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,720)).clone(300)).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigWaitToRestore.setDescription('The Wait To Restore period in seconds.\n\n         After clearing of a condition that necessitated an\n         automatic switch, the wait to restore period must elapse\n         before reverting. This is intended to avoid rapid switch\n         oscillations.\n\n         GR-253-CORE specifies a Wait To Restore range of 5 to 12\n         minutes. G.783 defines a 5 to 12 minute Wait To Restore\n         range in section 5.4.1.1.3, but also allows for a shorter\n         WTR period in  Table 2-1,\n         WaitToRestore value (MI_WTRtime: 0..(5)..12 minutes).\n\n         This object may not be modified if the associated\n         apsConfigRowStatus object is equal to active(1).')
apsConfigCreationTime = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigCreationTime.setDescription('The value of sysUpTime at the time the row was\n         created')
apsConfigStorageType = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 1, 2, 1, 11), StorageType().clone('nonVolatile')).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsConfigStorageType.setDescription("The storage type for this conceptual row.\n\n\n         Conceptual rows having the value 'permanent' need not\n         allow write-access to any columnar objects in the row.")
apsStatusTable = MibTable((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2), )
if mibBuilder.loadTexts: apsStatusTable.setDescription('This table provides status information about APS groups that have\n         been configured on the system.')
apsStatusEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1), )
apsConfigEntry.registerAugmentions(("APS-MIB", "apsStatusEntry"))
apsStatusEntry.setIndexNames(*apsConfigEntry.getIndexNames())
if mibBuilder.loadTexts: apsStatusEntry.setDescription('A conceptual row in the apsStatusTable.')
apsStatusK1K2Rcv = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 1), ApsK1K2()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusK1K2Rcv.setDescription('The current value of the K1 and K2 bytes received on the\n\n\n         protection channel.')
apsStatusK1K2Trans = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 2), ApsK1K2()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusK1K2Trans.setDescription('The current value of the K1 and K2 bytes transmitted on the\n         protection channel.')
apsStatusCurrent = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 3), Bits().clone(namedValues=NamedValues(("modeMismatch", 0), ("channelMismatch", 1), ("psbf", 2), ("feplf", 3), ("extraTraffic", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusCurrent.setDescription('The current status of the APS group.\n\n         modeMismatch\n\n         Modes other than 1+1 unidirectional monitor protection line\n         K2 bit 5, which indicates the architecture and K2 bits\n         6-8, which indicate if the mode is unidirectional or\n         bidirectional. A conflict between the current local mode\n         and the received K2 mode information constitutes a\n         mode mismatch.\n\n         channelMismatch\n\n         This bit indicates a  mismatch between the transmitted K1 channel\n         and the received K2 channel has been detected.\n\n         psbf\n\n         This bit indicates a Protection Switch Byte Failure (PSBF) is\n         in effect. This condition occurs when either an inconsistent\n         APS byte or an invalid code is detected. An inconsistent APS\n         byte occurs when no three consecutive K1 bytes of the last 12\n         successive frames are identical, starting with the last frame\n         containing a previously consistent byte. An invalid code occurs\n         when the incoming K1 byte contains an unused code or a code\n\n\n         irrelevant for the specific switching operation (e.g., Reverse\n         Request while no switching request is outstanding) in three\n         consecutive frames. An invalid code also occurs when the incoming\n         K1 byte contains an invalid channel number in three consecutive\n         frames.\n\n         feplf\n\n         Modes other than 1+1 unidirectional monitor the K1 byte\n         for Far-End Protection-Line failures. A Far-End\n         Protection-Line defect is declared based on receiving\n         SF on the protection line.\n\n         extraTraffic\n\n         This bit indicates whether extra traffic is currently being\n         accepted on the protection line. ')
apsStatusModeMismatches = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusModeMismatches.setDescription('A count of Mode Mismatch conditions.\n\n         Discontinuities in the value of this counter can occur at\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsStatusDiscontinuityTime.')
apsStatusChannelMismatches = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusChannelMismatches.setDescription('A count of Channel Mismatch conditions.\n\n         Discontinuities in the value of this counter can occur at\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsStatusDiscontinuityTime.')
apsStatusPSBFs = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusPSBFs.setDescription('A count of Protection Switch Byte Failure conditions.\n         This condition occurs when either an inconsistent APS\n         byte or an invalid code is detected. An inconsistent APS\n         byte occurs when no three consecutive K1 bytes of the last\n         12 successive frames are identical, starting with the last\n         frame containing a previously consistent byte. An invalid\n         code occurs when the incoming K1 byte contains an unused\n         code or a code irrelevant for the specific switching operation\n         (e.g., Reverse Request while no switching request is outstanding)\n         in three consecutive frames. An invalid code also occurs\n         when the incoming K1 byte contains an invalid channel number\n         in three consecutive frames.\n\n         Discontinuities in the value of this counter can occur at\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsStatusDiscontinuityTime.')
apsStatusFEPLFs = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusFEPLFs.setDescription('A count of Far-End Protection-Line Failure conditions.\n         This condition is declared based on receiving SF on\n         the protection line in the K1 byte.\n\n         Discontinuities in the value of this counter can occur at\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsStatusDiscontinuityTime.')
apsStatusSwitchedChannel = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 8), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusSwitchedChannel.setDescription('This field is set to the number of the channel that is currently\n         switched to protection. The value 0 indicates no channel is\n         switched to protection. The values 1-14 indicate that working\n         channel is switched to protection.')
apsStatusDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 2, 1, 9), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsStatusDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion at which\n         any one or more of this APS group's counters suffered a\n         discontinuity.  The relevant counters are the specific\n         instances associated with this APS group of any Counter32\n         object contained in apsStatusTable. If no such\n         discontinuities have occurred since the last re-initialization\n         of the local management subsystem, then this object contains\n         a zero value.")
apsMap = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 3))
apsChanLTEs = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 3, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanLTEs.setDescription('The count of SONET LTE interfaces on the system.\n         Each interface that is included has an ifType value of sonet(39).')
apsMapTable = MibTable((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 3, 2), )
if mibBuilder.loadTexts: apsMapTable.setDescription('This table lists the SONET LTE interfaces on the system.\n         Each interface that is listed has an ifType value of sonet(39).')
apsMapEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 3, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: apsMapEntry.setDescription('A conceptual row in the apsMapTable.')
apsMapGroupName = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 3, 2, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32))).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsMapGroupName.setDescription('A textual name for the APS group which this channel is\n         included in. If the channel is not part of an APS group\n         this value is set to a string of size 0.\n\n         When an instance of apsChanConfigIfIndex is set equal to an\n         instance of ifIndex that has an  ifType value of sonet(39),\n         apsMapGroupName is set equal to the corresponding value of\n         apsChanConfigGroupName.\n\n         If an instance of ifIndex that has an  ifType value of sonet(39)\n         ceases to be equal to an instance of apsChanConfigIfIndex, either\n         because of a change in the value of apsChanConfigIfIndex, or\n         because of row deletion in the ApsChanConfigTable, apsMapGroupName\n         is set to a string of size 0.')
apsMapChanNumber = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 3, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-1,14))).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsMapChanNumber.setDescription('This field is set to a unique channel number within an APS group.\n         The value 0 indicates the null channel. The values 1-14 define a\n         working channel. If the SONET LTE is not part of an APS group this\n         value is set to -1.\n\n         When an instance of apsChanConfigIfIndex is set equal to an\n         instance of ifIndex that has an  ifType value of sonet(39),\n         apsMapChanNumber is set equal to the corresponding value of\n         apsChanConfigNumber.\n\n         If an instance of ifIndex that has an  ifType value of sonet(39)\n         ceases to be equal to an instance of apsChanConfigIfIndex, either\n         because of a change in the value of apsChanConfigIfIndex, or\n         because of row deletion in the ApsChanConfigTable,\n         apsMapChanNumber is set to -1.')
apsChanConfigTable = MibTable((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4), )
if mibBuilder.loadTexts: apsChanConfigTable.setDescription('This table lists the APS channels that have been configured\n         in APS groups.')
apsChanConfigEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4, 1), ).setIndexNames((0, "APS-MIB", "apsChanConfigGroupName"), (0, "APS-MIB", "apsChanConfigNumber"))
if mibBuilder.loadTexts: apsChanConfigEntry.setDescription('A conceptual row in the apsChanConfigTable.')
apsChanConfigGroupName = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32)))
if mibBuilder.loadTexts: apsChanConfigGroupName.setDescription('A textual name for the APS group which this channel is\n         included in.')
apsChanConfigNumber = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,14)))
if mibBuilder.loadTexts: apsChanConfigNumber.setDescription('This field is set to a unique channel number within an APS group.\n         The value 0 indicates the null channel. The values 1-14 define a\n         working channel.\n\n         This field must be assigned a unique number within the group.')
apsChanConfigRowStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4, 1, 3), RowStatus()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanConfigRowStatus.setDescription('The status of this APS channel entry.\n\n         An entry may not exist in the active state unless all\n         objects in the entry have an appropriate value.\n\n         A row in the apsChanConfigTable may not be created,\n         deleted, set to notInService or otherwise modified\n         if the apsChanConfigGroupName value is equal to an\n         apsConfigName value and the associated apsConfigRowStatus\n         object is equal to active. However, if the apsConfigRowStatus\n         object is equal to notInService, a row may be created, deleted\n         or modified. In other words, a channel may not be added, deleted\n         or modified if the group is active.\n\n         A row may be created with an apsChanConfigGroupName value\n         that is not equal to any existing instance of apsConfigName.\n         This action is the initial step in adding a SONET LTE to a\n         new APS group.\n\n         If this object is set to destroy, the associated instance\n         of apsMapGroupName will be set to a string of size 0 and\n         the apsMapChanNumber will be set to -1. The channel status\n         entry will also be deleted by this action.\n\n         apsChanConfigNumber must be set to a unique channel number within\n         the APS group. The value 0 indicates the null channel.\n         The values 1-14 define a working channel. When an attempt is\n         made to set the  corresponding apsConfigRowStatus field to\n         active the apsChanConfigNumber values of all entries with equal\n         apsChanConfigGroupName fields must represent a set of consecutive\n         integer values beginning with 0 or 1, depending on the architecture\n         of the group, and ending with n, where n is  greater than or\n         equal to 1 and less than or equal to 14. Otherwise, the error\n         inconsistentValue is returned to the apsConfigRowStatus\n         set attempt.')
apsChanConfigIfIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4, 1, 4), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanConfigIfIndex.setDescription('The Interface Index assigned to a SONET LTE. This is an\n         interface with ifType sonet(39). The value of this object\n         must be unique among all instances of apsChanConfigIfIndex.\n         In other words, a particular SONET LTE can only be configured in\n         one APS group.\n\n         This object cannot be set if the apsChanConfigGroupName instance\n         associated with this row is equal to an instance of apsConfigName\n         and the corresponding apsConfigRowStatus object is set to active.\n         In other words this value cannot be changed if the APS group is\n         active. However, this value may be changed if the apsConfigRowStatus\n         value is equal to notInService.')
apsChanConfigPriority = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("low", 1), ("high", 2),)).clone('low')).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanConfigPriority.setDescription('The priority of the channel.\n\n         This field deterimines whether high or low priority\n         SD and SF codes are used in K1 requests.\n\n         This field is only applicable if the channel is to be included in\n         a group using the 1:n architecture. It is not applicable if the\n         channel is to be included in a group using the 1+1 architecture,\n         and is ignored in that case.\n\n         This object cannot be set if the apsChanConfigGroupName instance\n         associated with this row is equal to an instance of apsConfigName\n         and the corresponding apsConfigRowStatus object is set to active.\n         In other words this value cannot be changed if the APS group is\n         active. However, this value may be changed if the\n         apsConfigRowStatus value is equal to notInService.')
apsChanConfigStorageType = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 4, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanConfigStorageType.setDescription("The storage type for this conceptual row.\n         Conceptual rows having the value 'permanent' need not\n         allow write-access to any columnar objects in the row.")
apsCommandTable = MibTable((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 5), )
if mibBuilder.loadTexts: apsCommandTable.setDescription('This table allows commands to be sent to configured APS groups.')
apsCommandEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 5, 1), ).setIndexNames((0, "APS-MIB", "apsChanConfigGroupName"), (0, "APS-MIB", "apsChanConfigNumber"))
if mibBuilder.loadTexts: apsCommandEntry.setDescription('A conceptual row in the apsCommandTable. This row exists only if\n         the associated apsConfigEntry is active.')
apsCommandSwitch = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 5, 1, 1), ApsSwitchCommand()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsCommandSwitch.setDescription('Allows the initiation of an APS switch command on the\n         APS group and channel specified by the index values.\n\n         When read this object returns the last command written\n         or noCmd if no command has been written to this\n         channel since initialization. The return of the last command\n         written does not imply that this command is currently in effect.\n         This request may have been preempted by a higher priority\n\n\n         local or remote request. In order to determine the\n         current state of the APS group it is necessary to read\n         the objects apsStatusK1K2Rcv and apsStatusK1K2Trans.\n\n         The value lockoutOfProtection should only be applied to the\n         protection line channel since that switch command prevents any of\n         the working channels from switching to the protection line.\n         Following the same logic, forcedSwitchProtectToWork and\n         manualSwitchProtectToWork should only be applied to the protection\n         line channel.\n\n         forcedSwitchWorkToProtect and manualSwitchWorkToProtect\n         should only be applied to a working channel.')
apsCommandControl = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 5, 1, 2), ApsControlCommand()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsCommandControl.setDescription('Allows the initiation of an APS control command on the\n         APS group and channel specified by the index values.\n\n         When read this object returns the last command written or\n         noCmd if no command has been written to this channel since\n         initialization.\n\n         This object does not apply to the protection line.')
apsChanStatusTable = MibTable((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6), )
if mibBuilder.loadTexts: apsChanStatusTable.setDescription('This table contains status information for all SONET LTE\n         interfaces that are included in APS groups.')
apsChanStatusEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1), )
apsChanConfigEntry.registerAugmentions(("APS-MIB", "apsChanStatusEntry"))
apsChanStatusEntry.setIndexNames(*apsChanConfigEntry.getIndexNames())
if mibBuilder.loadTexts: apsChanStatusEntry.setDescription('A conceptual row in the apsChanStatusTable.')
apsChanStatusCurrent = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1, 1), Bits().clone(namedValues=NamedValues(("lockedOut", 0), ("sd", 1), ("sf", 2), ("switched", 3), ("wtr", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanStatusCurrent.setDescription('Indicates the current state of the port.\n\n         lockedOut\n\n         This bit, when applied to a working channel, indicates that\n         the channel is prevented from switching to the protection line.\n         When applied to the null channel, this bit indicates that no\n         working channel may switch to the protection line.\n\n         sd\n\n         A signal degrade condition is in effect.\n\n         sf\n\n         A signal failure condition is in effect.\n\n         switched\n\n         The switched bit is applied to a working channel if that\n         channel is currently switched to the protection line.\n\n\n         wtr\n\n         A Wait-to-Restore state is in effect.')
apsChanStatusSignalDegrades = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanStatusSignalDegrades.setDescription('A count of Signal Degrade conditions. This condition\n         occurs when the line Bit Error Rate exceeds the currently\n         configured value of the relevant instance of\n         apsConfigSdBerThreshold.\n\n         Discontinuities in the value of this counter can occur at\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsChanStatusDiscontinuityTime.')
apsChanStatusSignalFailures = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanStatusSignalFailures.setDescription('A count of Signal Failure conditions that have been\n         detected on the incoming signal. This condition occurs\n         when a loss of signal, loss of frame, AIS-L or a Line\n         bit error rate exceeding the currently configured value of\n         the relevant instance of apsConfigSfBerThreshold.\n\n         Discontinuities in the value of this counter can occur at\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsChanStatusDiscontinuityTime.')
apsChanStatusSwitchovers = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanStatusSwitchovers.setDescription('When queried with index value apsChanConfigNumber other than 0,\n         this object will return the number of times this channel has\n\n\n         switched to the protection line.\n\n         When queried with index value apsChanConfigNumber set to 0,\n         which is the protection line, this object will return the\n         number of times that any working channel has been switched\n         back to the working line from this protection line.\n\n         Discontinuities in the value of this counter can occur at\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsChanStatusDiscontinuityTime.')
apsChanStatusLastSwitchover = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanStatusLastSwitchover.setDescription('When queried with index value apsChanConfigNumber other than 0,\n         this object will return the value of sysUpTime when this\n         channel last completed a switch to the protection line. If this\n         channel has never switched to the protection line, the value\n         0 will be returned.\n\n         When queried with index value apsChanConfigNumber set to 0,\n         which is the protection line, this object will return the\n         value of sysUpTime the last time that a working channel was\n         switched back to the working line from this protection line.\n         If no working channel has ever switched back to the working\n         line from this protection line, the value 0 will be returned.')
apsChanStatusSwitchoverSeconds = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanStatusSwitchoverSeconds.setDescription('The cumulative Protection Switching Duration (PSD) time in\n         seconds. For a working channel, this is the cumulative number\n         of seconds that service was carried on the protection line.\n         For the protection line, this is the cumulative number of\n         seconds that the protection line has been used to carry any\n         working channel traffic. This information is only valid if\n         revertive switching is enabled. The value 0 will be returned\n         otherwise.\n\n         Discontinuities in the value of this counter can occur at\n\n\n         re-initialization of the management system, and at other\n         times as indicated by the value of\n         apsChanStatusDiscontinuityTime. For example, if the value\n         of an instance of apsChanStatusSwitchoverSeconds changes\n         from a non-zero value to zero due to revertive switching\n         being disabled, it is expected that the corresponding\n         value of apsChanStatusDiscontinuityTime will be updated\n         to reflect the time of the configuration change.\n         ')
apsChanStatusDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 6, 1, 7), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsChanStatusDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion at which\n         any one or more of this channel's counters suffered a\n         discontinuity.  The relevant counters are the specific\n         instances associated with this channel of any Counter32\n         object contained in apsChanStatusTable. If no such\n         discontinuities have occurred since the last re-initialization\n         of the local management subsystem, then this object contains\n         a zero value.")
apsNotificationEnable = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 24, 1, 7), Bits().clone(namedValues=NamedValues(("switchover", 0), ("modeMismatch", 1), ("channelMismatch", 2), ("psbf", 3), ("feplf", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: apsNotificationEnable.setDescription('Provides the ability to enable and disable notifications\n         defined in this MIB.\n\n         switchover\n\n         Indicates  apsEventSwitchover notifications\n         should be generated.\n\n         modeMismatch\n\n         Indicates  apsEventModeMismatch notifications\n\n\n         should be generated.\n\n         channelMismatch\n\n         Indicates  apsEventChannelMismatch notifications\n         should be generated.\n\n         psbf\n\n         Indicates  apsEventPSBF notifications\n         should be generated.\n\n         feplf\n\n         Indicates  apsEventFEPLF notifications\n         should be generated. ')
apsNotificationsPrefix = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 2, 0))
apsEventSwitchover = NotificationType((1, 3, 6, 1, 4, 1, 2636, 3, 24, 2, 0, 1)).setObjects(*(("APS-MIB", "apsChanStatusSwitchovers"), ("APS-MIB", "apsChanStatusCurrent"),))
if mibBuilder.loadTexts: apsEventSwitchover.setDescription('An apsEventSwitchover notification is sent when the\n        value of an instance of apsChanStatusSwitchovers increments.')
apsEventModeMismatch = NotificationType((1, 3, 6, 1, 4, 1, 2636, 3, 24, 2, 0, 2)).setObjects(*(("APS-MIB", "apsStatusModeMismatches"), ("APS-MIB", "apsStatusCurrent"),))
if mibBuilder.loadTexts: apsEventModeMismatch.setDescription('An apsEventModeMismatch notification is sent when the\n        value of an instance of apsStatusModeMismatches increments.')
apsEventChannelMismatch = NotificationType((1, 3, 6, 1, 4, 1, 2636, 3, 24, 2, 0, 3)).setObjects(*(("APS-MIB", "apsStatusChannelMismatches"), ("APS-MIB", "apsStatusCurrent"),))
if mibBuilder.loadTexts: apsEventChannelMismatch.setDescription('An apsEventChannelMismatch notification is sent when the\n        value of an instance of apsStatusChannelMismatches increments.')
apsEventPSBF = NotificationType((1, 3, 6, 1, 4, 1, 2636, 3, 24, 2, 0, 4)).setObjects(*(("APS-MIB", "apsStatusPSBFs"), ("APS-MIB", "apsStatusCurrent"),))
if mibBuilder.loadTexts: apsEventPSBF.setDescription('An apsEventPSBF notification is sent when the\n        value of an instance of apsStatusPSBFs increments.')
apsEventFEPLF = NotificationType((1, 3, 6, 1, 4, 1, 2636, 3, 24, 2, 0, 5)).setObjects(*(("APS-MIB", "apsStatusFEPLFs"), ("APS-MIB", "apsStatusCurrent"),))
if mibBuilder.loadTexts: apsEventFEPLF.setDescription('An apsEventFEPLFs notification is sent when the\n        value of an instance of apsStatusFEPLFs increments.')
apsGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1))
apsCompliances = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 2))
apsFullCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 2, 1)).setObjects(*(("APS-MIB", "apsConfigGeneral"), ("APS-MIB", "apsStatusGeneral"), ("APS-MIB", "apsChanGeneral"),))
if mibBuilder.loadTexts: apsFullCompliance.setDescription('When this MIB is implemented with support for read-create, then\n        such an implementation can claim read/write compliance. Linear APS\n        groups can then be both monitored and configured with this MIB.\n\n        Note that An agent is not required to process SNMP Set Requests that\n        affect multiple control objects within this MIB. This is intended to\n        simplify the processing of Set Requests for the various control\n        tables by eliminating the possibility that a single Set PDU will\n        contain multiple varbinds which are in conflict. ')
apsReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 2, 2)).setObjects(*(("APS-MIB", "apsConfigGeneral"), ("APS-MIB", "apsStatusGeneral"), ("APS-MIB", "apsChanGeneral"),))
if mibBuilder.loadTexts: apsReadOnlyCompliance.setDescription('When this MIB is implemented without support for read-create\n         (i.e. in read-only mode), then that implementation can claim\n         read-only compliance. In that case, linear APS groups can be\n         monitored but cannot be configured with this MIB.')
apsConfigGeneral = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 1)).setObjects(*(("APS-MIB", "apsConfigMode"), ("APS-MIB", "apsConfigRevert"), ("APS-MIB", "apsConfigDirection"), ("APS-MIB", "apsConfigExtraTraffic"), ("APS-MIB", "apsConfigSdBerThreshold"), ("APS-MIB", "apsConfigSfBerThreshold"), ("APS-MIB", "apsConfigCreationTime"), ("APS-MIB", "apsConfigRowStatus"), ("APS-MIB", "apsConfigStorageType"), ("APS-MIB", "apsNotificationEnable"),))
if mibBuilder.loadTexts: apsConfigGeneral.setDescription('A collection of apsConfigTable objects providing configuration\n         information applicable to all linear APS groups.')
apsConfigWtr = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 2)).setObjects(*(("APS-MIB", "apsConfigWaitToRestore"),))
if mibBuilder.loadTexts: apsConfigWtr.setDescription('The apsConfigTable object that provides information which is\n         applicable to groups supporting a configurable WTR period.')
apsCommandOnePlusOne = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 3)).setObjects(*(("APS-MIB", "apsCommandSwitch"),))
if mibBuilder.loadTexts: apsCommandOnePlusOne.setDescription('The  apsCommandTable object which is applicable to groups\n         implementing the linear APS 1+1 architecture. Also, set operations\n         must be supported.')
apsCommandOneToN = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 4)).setObjects(*(("APS-MIB", "apsCommandSwitch"), ("APS-MIB", "apsCommandControl"),))
if mibBuilder.loadTexts: apsCommandOneToN.setDescription('A collection of apsCommandTable objects which are applicable to\n\n\n         groups implementing the linear APS 1:n architecture. Also, set\n         operations must be supported.')
apsStatusGeneral = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 5)).setObjects(*(("APS-MIB", "apsStatusK1K2Rcv"), ("APS-MIB", "apsStatusK1K2Trans"), ("APS-MIB", "apsStatusCurrent"), ("APS-MIB", "apsStatusModeMismatches"), ("APS-MIB", "apsStatusChannelMismatches"), ("APS-MIB", "apsStatusPSBFs"), ("APS-MIB", "apsStatusFEPLFs"), ("APS-MIB", "apsStatusSwitchedChannel"), ("APS-MIB", "apsStatusDiscontinuityTime"),))
if mibBuilder.loadTexts: apsStatusGeneral.setDescription('A collection of apsStatusTable objects providing status information\n         applicable to all linear APS groups.')
apsChanGeneral = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 6)).setObjects(*(("APS-MIB", "apsChanConfigIfIndex"), ("APS-MIB", "apsChanConfigRowStatus"), ("APS-MIB", "apsChanConfigStorageType"), ("APS-MIB", "apsChanStatusCurrent"), ("APS-MIB", "apsChanStatusSignalDegrades"), ("APS-MIB", "apsChanStatusSignalFailures"), ("APS-MIB", "apsChanStatusSwitchovers"), ("APS-MIB", "apsChanStatusLastSwitchover"), ("APS-MIB", "apsChanStatusSwitchoverSeconds"), ("APS-MIB", "apsChanStatusDiscontinuityTime"),))
if mibBuilder.loadTexts: apsChanGeneral.setDescription('A collection of channel objects providing information applicable to\n         all linear APS channels.')
apsChanOneToN = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 7)).setObjects(*(("APS-MIB", "apsChanConfigPriority"),))
if mibBuilder.loadTexts: apsChanOneToN.setDescription('The apsChanConfigTable object that provides information which is only\n         applicable to groups implementing the linear APS 1:n architecture.')
apsTotalsGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 8)).setObjects(*(("APS-MIB", "apsConfigGroups"), ("APS-MIB", "apsChanLTEs"),))
if mibBuilder.loadTexts: apsTotalsGroup.setDescription('A collection of objects providing optional counts of configured APS\n         groups and SONET LTE interfaces.')
apsMapGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 9)).setObjects(*(("APS-MIB", "apsMapGroupName"), ("APS-MIB", "apsMapChanNumber"),))
if mibBuilder.loadTexts: apsMapGroup.setDescription('A collection of apsMapTable objects providing a mapping\n         from sonet(39) InterfaceIndex to group name and channel\n         number for assigned APS channels and a list of unassigned\n         sonet(39) interfaces.')
apsEventGroup = NotificationGroup((1, 3, 6, 1, 4, 1, 2636, 3, 24, 3, 1, 10)).setObjects(*(("APS-MIB", "apsEventSwitchover"), ("APS-MIB", "apsEventModeMismatch"), ("APS-MIB", "apsEventChannelMismatch"), ("APS-MIB", "apsEventPSBF"), ("APS-MIB", "apsEventFEPLF"),))
if mibBuilder.loadTexts: apsEventGroup.setDescription('A collection of SONET linear APS notifications.')
mibBuilder.exportSymbols("APS-MIB", apsChanStatusCurrent=apsChanStatusCurrent, apsChanStatusSignalDegrades=apsChanStatusSignalDegrades, apsChanLTEs=apsChanLTEs, apsNotificationsPrefix=apsNotificationsPrefix, apsConfigEntry=apsConfigEntry, apsConfigName=apsConfigName, apsChanStatusSignalFailures=apsChanStatusSignalFailures, apsEventPSBF=apsEventPSBF, apsChanConfigPriority=apsChanConfigPriority, apsStatusDiscontinuityTime=apsStatusDiscontinuityTime, apsStatusSwitchedChannel=apsStatusSwitchedChannel, apsMapEntry=apsMapEntry, apsConfigGroups=apsConfigGroups, apsChanConfigTable=apsChanConfigTable, apsStatusGeneral=apsStatusGeneral, apsCommandTable=apsCommandTable, apsChanConfigStorageType=apsChanConfigStorageType, apsFullCompliance=apsFullCompliance, apsConfig=apsConfig, apsChanConfigIfIndex=apsChanConfigIfIndex, apsEventSwitchover=apsEventSwitchover, apsCommandOnePlusOne=apsCommandOnePlusOne, apsCommandSwitch=apsCommandSwitch, apsEventChannelMismatch=apsEventChannelMismatch, apsStatusModeMismatches=apsStatusModeMismatches, apsConfigExtraTraffic=apsConfigExtraTraffic, apsReadOnlyCompliance=apsReadOnlyCompliance, ApsSwitchCommand=ApsSwitchCommand, apsConfigWtr=apsConfigWtr, apsStatusK1K2Trans=apsStatusK1K2Trans, apsStatusFEPLFs=apsStatusFEPLFs, apsGroups=apsGroups, apsMapGroupName=apsMapGroupName, apsStatusEntry=apsStatusEntry, apsStatusTable=apsStatusTable, apsStatusPSBFs=apsStatusPSBFs, PYSNMP_MODULE_ID=apsMIB, apsConfigDirection=apsConfigDirection, apsChanStatusTable=apsChanStatusTable, apsConfigTable=apsConfigTable, apsMapTable=apsMapTable, ApsK1K2=ApsK1K2, apsCommandOneToN=apsCommandOneToN, apsConfigStorageType=apsConfigStorageType, apsConfigSfBerThreshold=apsConfigSfBerThreshold, apsChanStatusDiscontinuityTime=apsChanStatusDiscontinuityTime, apsCommandControl=apsCommandControl, apsChanStatusEntry=apsChanStatusEntry, apsMIBObjects=apsMIBObjects, apsMapGroup=apsMapGroup, apsMapChanNumber=apsMapChanNumber, apsChanConfigRowStatus=apsChanConfigRowStatus, apsTotalsGroup=apsTotalsGroup, apsConfigCreationTime=apsConfigCreationTime, apsStatusCurrent=apsStatusCurrent, apsEventFEPLF=apsEventFEPLF, apsConfigMode=apsConfigMode, ApsControlCommand=ApsControlCommand, apsMap=apsMap, apsConfigRevert=apsConfigRevert, apsChanOneToN=apsChanOneToN, apsChanConfigGroupName=apsChanConfigGroupName, apsCommandEntry=apsCommandEntry, apsEventGroup=apsEventGroup, apsChanGeneral=apsChanGeneral, apsChanStatusLastSwitchover=apsChanStatusLastSwitchover, apsMIBConformance=apsMIBConformance, apsConfigRowStatus=apsConfigRowStatus, apsConfigSdBerThreshold=apsConfigSdBerThreshold, apsChanStatusSwitchovers=apsChanStatusSwitchovers, apsChanStatusSwitchoverSeconds=apsChanStatusSwitchoverSeconds, apsNotificationEnable=apsNotificationEnable, apsConfigGeneral=apsConfigGeneral, apsMIB=apsMIB, apsChanConfigNumber=apsChanConfigNumber, apsCompliances=apsCompliances, apsEventModeMismatch=apsEventModeMismatch, apsStatusK1K2Rcv=apsStatusK1K2Rcv, apsMIBNotifications=apsMIBNotifications, apsChanConfigEntry=apsChanConfigEntry, apsStatusChannelMismatches=apsStatusChannelMismatches, apsConfigWaitToRestore=apsConfigWaitToRestore)
